@@ -3,14 +3,12 @@ from pyqode.qt.QtTest import QTest
 from pyqode.python import panels
 
 from ..helpers import editor_open
-from ..helpers import preserve_editor_config
 
 
 def get_panel(editor):
     return editor.panels.get(panels.SymbolBrowserPanel)
 
 
-@preserve_editor_config
 def test_empty_editor(editor):
     editor.panels.clear()
     editor.modes.clear()
@@ -25,6 +23,7 @@ def test_empty_editor(editor):
 
 @editor_open(__file__)
 def test_goto_definition(editor):
+    editor.show()
     QTest.qWait(1000)
     panel = get_panel(editor)
     line = TextHelper(editor).current_line_nbr()
